@@ -270,9 +270,12 @@ def map_attribute_type(t: str, col):
     elif t == "integer":
         return Integer
     elif t == "numeric":
-        return DECIMAL(
-            scale=col.get("scale", 4), precision=col.get("precision", 15)
-        )
+        scale = col.get("scale", 4)
+        precision = col.get("precision", 15)
+        if len(scale) > 0 and len(precision) > 0:
+            return DECIMAL(scale=scale, precision=precision)
+        else:
+            return DECIMAL()
     elif t == "timestamp":
         return TIMESTAMP
     elif t == "boolean":
